<?php

class stemp {

	/**
	 * Array of config options
	 * @var array
	 */
	public $config = array ();
	
	/**
	 * Template Name
	 * @var string
	 */
	public $template;
	
	/**
	 * Cache Option
	 * @var boolean
	 */
	private $cachefile = false;
	
	/**
	 * Array of customa variables
	 * @var array
	 */
	public $customvars = array ();
	
	/**
	 * Custom header file
	 * @var string
	 */
	public $header = 'header';
	
	/**
	 * Custom footer file
	 * @var string
	 */
	public $footer = 'footer';
	
	/**
	 * Instance of DB Functions
	 * @var array
	 */
	public $db;

	/**
	 * Error Count
	 * @var int
	 */
	private $errorcount = 0;
	
	/**
	 * Array of available plugins
	 * @var array
	 */
	public $plugins;
	
	/**
	 * Class constructor, initializes basic system properties
	 */
	function __construct() {
		$config = '';
		$plugins = '';
		
		set_exception_handler ( 'trigger_error' );
		
		include (ROOTDIR . "/includes/dbfunctions.php");
		include (ROOTDIR . "/config.php");
		
		$this->config = $config;
		$this->db = new db ();
		$this->plugins = $plugins;
		
		if ($this->config ['usessl'])
			$this->secure_ssl ();
	
	}
	
	/**
	 * trigger system error
	 * 
	 * @param string $error_msg 
	 */
	public function trigger_error($error_msg) {
		$this->errorcount ++;
		echo "<b>System Error:</b> $error_msg<br>\n";
	
	}
	
	
	/**
	 * enables the debug output
	 */ 
	public function enable_debug() {
		error_reporting ( E_ALL );
	
	}
	
	/**
	 * redirects the user
	 * 
	 * @param string $page, URI to redirect
	 */
	public function redirect($page) {
		$host = $_SERVER ['HTTP_HOST'];
		$uri = rtrim ( dirname ( $_SERVER ['PHP_SELF'] ), '/\\' );
		
		header ( "Location: http://$host$uri/$page" );
	}
	
	/**
	 * if enabled, redirects the user to the secure version of the viewing page
	 */
	private function secure_ssl() {
		$in_ssl = (! isset ( $_SERVER ['HTTPS'] ) or $_SERVER ['HTTPS'] == 'off') ? false : true;
		if (! $in_ssl) {
			$baseurl = "https://" . $_SERVER ['HTTP_HOST'];
			$req = $_SERVER ['REQUEST_URI'];
			header ( "Location:$baseurl$req" );
			exit ();
		}
	
	}
	
	/**
	 * Gets the current page the user is vieweing (ssl / non-ssl)
	 * 
	 * @return boolean
	 */
	public function get_ssl_status() {
		
		return (! isset ( $_SERVER ['HTTPS'] ) or $_SERVER ['HTTPS'] == 'off') ? false : true;
	
	}
	
	/**
	 * Configure custom header
	 * @param string $header
	 */
	public function set_custom_header($header) {
		
		$this->header = $header;
	}
	
	/**
	 * Configure custom header
	 */
	public function enable_cache() {
		
		return $this->cachefile = true;
	}
	
	
	/**
	 * Tells if the actual page is cached
	 *
	 * @return boolean
	 */
	public function is_cached() {
		
		if ($this->cachefile) {
			
			$cachefile = CACHE_PATH . basename ( $_SERVER ['SCRIPT_NAME'], '.php' );
			
			return (file_exists ( $cachefile )) ? true : false;
		}
		
		return false;
	}
	
	/**
	 * Configure custom footer
	 * @param string $footer
	 */
	public function set_custom_footer($footer) {
		
		$this->footer = $footer;
	
	}
	
	/**
	 * Outputs the selected template + (header, footer)
	 * 
	 * @param string | $ template name
	 */
	public function template_include($template) {
		
		$this->template = $template;
		$customvars = $this->customvars;
		
		$header = ROOTDIR . '/' . $this->config ['templates_folder'] . '/' . $this->header . ".php";
		$template = ROOTDIR . '/' . $this->config ['templates_folder'] . '/' . $template . ".php";
		$footer = ROOTDIR . '/' . $this->config ['templates_folder'] . '/' . $this->footer . ".php";
		
		if (! file_exists ( $header ))
			$this->trigger_error ( 'The header template files is missing' );
		
		if (! file_exists ( $template ))
			$this->trigger_error ( 'The selected template files is missing' );
		
		if (! file_exists ( $footer ))
			$this->trigger_error ( 'The footer template files is missing' );
		
		if ($this->errorcount > 0) {
			echo 'You will need to fix the above errors before the script can be executed';
			exit ();
		}
		
		if ($this->cachefile) {
			$cachedir = CACHE_PATH;
			$cachetime = 432000;
			
			$cachefile = $cachedir . basename ( $_SERVER ['SCRIPT_NAME'], '.php' );
			
			$cachelast = (file_exists ( $cachefile )) ? filemtime ( $cachefile ) : 0;
			
			if (time () - $cachetime < $cachelast) {
				readfile ( $cachefile );
				exit ();
			}
			ob_start ();
		
		}
		include ($header);
		include ($template);
		include ($footer);
		
		if ($this->cachefile) {
			$fp = fopen ( $cachefile, 'w' );
			
			fwrite ( $fp, ob_get_contents () );
			fclose ( $fp );
			
			ob_end_flush ();
		}
	}

}

?>
