<?php

/**
 * Formats an email HTML string according to parameters
 * 
 * @param array parameters (ordered as "$key = $value")
 * 
 * address = e-mail address
 * text = (optional) text to display, default is address
 * encode = (optional) can be one of:
 * none:no encoding (default)
 * javascript : encode with javascript
 * hex : encode with hexidecimal (no javascript)
 * cc = (optional) address(es) to carbon copy
 * bcc = (optional) address(es) to blind carbon copy
 * subject = (optional) e-mail subject
 * 
 * ie: $params ['address'] = "me@domain.com";
 * 
 * @return string | formatted source text
 */
function mailto_format(stemp &$stemp, array $params) {
	
	$address = '';
	$text = '';
	$encode = '';
	$cc = '';
	$bcc = '';
	$subject = '';
	
	extract ( $params );
	
	if (empty ( $address )) {
		$stemp->trigger_error ( _ ( "mailto: missing 'address' parameter" ) );
		return;
	}
	
	$text = (empty ( $text )) ? $address : $text;
	
	$mail_parms = array ();
	if (! empty ( $cc )) {
		$mail_parms [] = 'cc=' . str_replace ( '%40', '@', rawurlencode ( $cc ) );
	}
	
	if (! empty ( $bcc )) {
		$mail_parms [] = 'bcc=' . str_replace ( '%40', '@', rawurlencode ( $bcc ) );
	}
	
	if (! empty ( $subject )) {
		$mail_parms [] = 'subject=' . rawurlencode ( $subject );
	}
	
	$mail_parm_vals = '';
	for($i = 0; $i < count ( $mail_parms ); $i ++) {
		$mail_parm_vals .= (0 == $i) ? '?' : '&';
		$mail_parm_vals .= $mail_parms [$i];
	}
	$address .= $mail_parm_vals;
	
	if (empty ( $encode )) {
		$encode = 'none';
	} elseif (! in_array ( $encode, array ('javascript', 'hex', 'none' ) )) {
		$stemp->trigger_error ( _ ( "mailto: 'encode' parameter must be none, javascript or hex" ) );
		return;
	}
	
	if ($encode == 'javascript') {
		$string = 'document.write(\'<a href="mailto:' . $address . '">' . $text . '</a>\');';
		
		$js_encode = '';
		for($x = 0; $x < strlen ( $string ); $x ++) {
			$js_encode .= '%' . bin2hex ( $string [$x] );
		}
		
		echo '<SCRIPT language="javascript">eval(unescape(\'' . $js_encode . '\'))</SCRIPT>';
	
	} elseif ($encode == 'hex') {
		
		preg_match ( '!^(.*)(\?.*)$!', $address, $match );
		if (! empty ( $match [2] )) {
			$stemp->trigger_error ( _ ( "mailto: hex encoding does not work with extra attributes. Try javascript." ) );
			return;
		}
		$address_encode = '';
		for($x = 0; $x < strlen ( $address ); $x ++) {
			if (preg_match ( '!\w!', $address [$x] )) {
				$address_encode .= '%' . bin2hex ( $address [$x] );
			} else {
				$address_encode .= $address [$x];
			}
		}
		$text_encode = '';
		for($x = 0; $x < strlen ( $text ); $x ++) {
			$text_encode .= '&#x' . bin2hex ( $text [$x] ) . ';';
		}
		
		return '<a href="mailto:' . $address_encode . '">' . $text_encode . '</a>';
	
	} else {
		// no encoding		
		return '<a href="mailto:' . $address . '">' . $text . '</a>';
	
	}

}

/**
 * Configures the Google Analytics Tracking Code
 */
function google_analytics(stemp &$stemp) {
	if ($stemp->config ['analytics']) {
		
		if ($stemp->config ['analytics_type'] == "standard" or $stemp->config ['analytics_type'] != "async") {
			$stemp->customvars ['googleanalytics'] = "
<!--Google Analytics Tracking Code-->			
<script type=\"text/javascript\">
var gaJsHost = ((\"https:\" == document.location.protocol) ? \"https://ssl.\" : \"http://www.\");
document.write(unescape(\"%3Cscript src='\" + gaJsHost + \"google-analytics.com/ga.js' type='text/javascript'%3E%3C/script%3E\"));
</script>
<script type=\"text/javascript\">
try{
var pageTracker = _gat._getTracker(\"" . $stemp->config ['analytics_ua'] . "\");
pageTracker._trackPageview();
} catch(err) {}</script>
<!--End Google Analytics Tracking Code-->	

";
		
		} else {
			$stemp->customvars ['googleanalytics'] = "
<!--Google Analytics Tracking Code-->				
<script type=\"text/javascript\">
  var _gaq = _gaq || [];
  _gaq.push(['_setAccount', '" . $stemp->config ['analytics_ua'] . "']);
  _gaq.push(['_trackPageview']);

  (function() {
    var ga = document.createElement('script'); ga.type = 'text/javascript'; ga.async = true;
    ga.src = ('https:' == document.location.protocol ? 'https://ssl' : 'http://www') + '.google-analytics.com/ga.js';
    var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(ga, s);
  })();
</script>
<!--End Google Analytics Tracking Code-->

";
		
		}
	}
}

?>