<?php

class html {
	
	/**
	 * This function is part of the Smarty framework
	 * It has been adapted to work with Simple Template
	 * 
	 * @author Monte Ohrt <monte at ohrt dot com> 
	 * @author Uwe Tews 
	 * 
	 * @param string $ 
	 * @param string $ 
	 * @param string $ 
	 * @return string 
	 */
	function string_replace($string, $find, $replace) {
		
		function custom_replace($find, $replace, $output) {
			$find_len = mb_strlen ( $find );
			$replace_len = mb_strlen ( $replace );
			$posistion = mb_strpos ( $output, $find, 0 );
			while ( $posistion !== false ) {
				$output = mb_substr ( $output, 0, $posistion ) . $replace . mb_substr ( $output, $posistion + $find_len );
				$posistion = mb_strpos ( $output, $find, $posistion + $replace_len );
			}
			return $output;
		
		}
		
		return (function_exists ( 'mb_substr' )) ? custom_replace ( $find, $replace, $string ) : str_replace ( $find, $replace, $string );
	
	}
	
	function html_lower($string) {
		return mb_strtolower ( $string );
	
	}
	
	function html_upper($string) {
		return mb_strtoupper ( $string );
	
	}
	
	/**
	 * This function is part of the Smarty framework
	 * It has been adapted to work with Simple Template

	 * @author   Monte Ohrt <monte at ohrt dot com>
	 * 
	 * @param string $string input string
	 * @param boolean $include_spaces include whitespace in the character count
	 * @return integer number of characters
	 */
	function count_characters($string, $spaces = true) {
		if ($spaces) {
			return (strlen ( $string ));
		}
		return strlen(preg_replace (' ', '', $string));
	}
	
	/**
	 * This function is part of the Smarty framework
	 * It has been adapted to work with Simple Template
	 * 
	 * @author Monte Ohrt <monte at ohrt dot com> 
	 * 
	 * @param string $string input string
	 * @param string $esc_type escape type
	 * @param string $char_set character set
	 * @return string escaped input string
	 */
	function escape_char($string, $esctype = 'spechtml', $char_set = 'UTF-8') {
		global $stemp;
		switch ($esctype) {
			case 'htmlall' :
				return htmlentities ( $string, ENT_QUOTES, $char_set );
			
			case 'spechtml' :
				return htmlspecialchars ( $string, ENT_QUOTES, $char_set );
			
			case 'url' :
				return rawurlencode ( $string );
			
			case 'hex' :
				// escape every character into hex
				$return = NULL;
				for($x = 0; $x < strlen ( $string ); $x ++) {
					$return .= '%' . bin2hex ( $string [$x] );
				}
				return $return;
			
			case 'mail' :
				// safe way to display e-mail address on a web page
				if (function_exists ( 'mb_str_replace' )) {
					return $this->string_replace ( array ('@', '.' ), array (' [AT] ', ' [DOT] ' ), $string );
				} else {
					return str_replace ( array ('@', '.' ), array (' [AT] ', ' [DOT] ' ), $string );
				}
			
			case 'nonstd' :
				// escape non-standard characters
				//we use "[NEWLINE]" to avoid errors
				$string = str_replace ( "\n", "[NEWLINE]", $string );
				$string = preg_replace ( '/[^(\x20-\x7F)]*/', '', $string );
				$string = str_replace ( "[NEWLINE]", "\n", $string );
				
				return $string;
			
			default :
				die ( _ ( "The string could not be escaped, invalid escape type" ) );
		}
	}
	
	function uc_string($string, $all = false) {
		
		return $output = ($all) ? ucwords ( $string ) : ucfirst ( $string );
	
	}
	
	/**
	 * This function is part of the Smarty framework
	 * It has been adapted to work with Simple Template
	 * 
	 * @author Monte Ohrt <monte at ohrt dot com> 
	 * @author credits to Duda <duda@big.hu> 

	 * @param array $params parameters
	 * Input:
	 * - file = file (and path) of image (required)
	 * - height = image height (optional, default actual height)
	 * - width = image width (optional, default actual width)
	 * - basedir = base directory for absolute paths, default
	 * is environment variable DOCUMENT_ROOT
	 * - path_prefix = prefix for path output (optional, default empty)
	 * @param object $smarty Smarty object
	 * @param object $template template object
	 * @return string 
	 */
	function html_image( array $params) {
		global $stemp;
		$alt = '';
		$file = '';
		$height = '';
		$width = '';
		$extra = '';
		$prefix = '';
		$suffix = '';
		$path_prefix = '';
		$basedir = '';
		
		foreach ( $params as $_key => $_val ) {
			switch ($_key) {
				case 'file' :
				case 'height' :
				case 'width' :
				case 'dpi' :
				case 'path_prefix' :
				case 'basedir' :
					$$_key = $_val;
					break;
				
				case 'alt' :
					if (! is_array ( $_val )) {
						$$_key = $_val;
					} else {
						$stemp->trigger_error ( _ ( "html_image: extra attribute '$_key' cannot be an array" ) );
					}
					break;
				
				case 'link' :
				case 'href' :
					$prefix = '<a href="' . $_val . '">';
					$suffix = '</a>';
					break;
				
				default :
					if (! is_array ( $_val )) {
						$extra .= ' ' . $_key . '="' . $_val . '"';
					} else {
						$stemp->trigger_error ( _ ( "html_image: extra attribute '$_key' cannot be an array" ) );
					}
					break;
			}
		}
		
		if (empty ( $file )) {
			$stemp->trigger_error ( _ ( "html_image: missing 'file' parameter" ) );
			return;
		}
		
		$_image_path = (substr ( $file, 0, 1 ) == '/') ? $basedir . $file : $file;
		
		if (! isset ( $params ['width'] ) || ! isset ( $params ['height'] )) {
			if (! $_image_data = @getimagesize ( $_image_path )) {
				if (! file_exists ( $_image_path )) {
					$stemp->trigger_error ( _ ( "html_image: unable to find '$_image_path'" ) );
					return;
				} else if (! is_readable ( $_image_path )) {
					$stemp->trigger_error ( _ ( "html_image: unable to read '$_image_path'" ) );
					return;
				} else {
					$stemp->trigger_error ( _ ( "html_image: '$_image_path' is not a valid image file" ) );
					return;
				}
			}
			
			if (! isset ( $params ['width'] )) {
				$width = $_image_data [0];
			}
			if (! isset ( $params ['height'] )) {
				$height = $_image_data [1];
			}
		}
		
		if (isset ( $params ['dpi'] )) {
			
			$dpi_default = (strstr ( $_SERVER ['HTTP_USER_AGENT'], 'Mac' )) ? 72 : 96;
			
			$_resize = $dpi_default / $params ['dpi'];
			$width = round ( $width * $_resize );
			$height = round ( $height * $_resize );
		}
		
		return $prefix . '<img src="' . $path_prefix . $file . '" alt="' . $alt . '" width="' . $width . '" height="' . $height . '"' . $extra . ' />' . $suffix;
	}
	
	/**
	 * This function is part of the Smarty framework
	 * It has been adapted to work with Simple Template
	 * 
	 * @author   Monte Ohrt <monte at ohrt dot com>
	 * 
	 * @param string
	 * @return integer
	 */
	function count_sentences($string) {
		// find periods with a word before but not after.
		preg_match_all ( '/[^\s]\.(?!\w)/', $string, $match );
		return $string;
	}
	
	/**
	 * This function is part of the Smarty framework
	 * It has been adapted to work with Simple Template
	 *
	 * @author   Monte Ohrt <monte at ohrt dot com>
	 * 
	 * @param string
	 * @param integer
	 * @param string
	 * @return string
	 */
	function string_indent($string, $chars_no = 4, $character = " ") {
		$output = str_repeat ( $character, $chars_no );
		$output = preg_replace ( '!^!m', $output, $string );
		return $output;
	}
	
	/**
	 * This function is part of the Smarty framework
	 * It has been adapted to work with Simple Template

	 * @author   Monte Ohrt <monte at ohrt dot com>
	 * 
	 * Atributes and their description available in {http://www.smarty.net//manual/en/language.function.popup.php}
	 * 
	 * @param array $params parameters
	 * @return string
	 */
	function create_popup(array $params) {
		global $stemp;
		$append = '';
		$text = '';
		$inarray = '';
		$function = '';
		$trigger = '';
		
		foreach ( $params as $_key => $_value ) {
			switch ($_key) {
				case 'text' :
				case 'trigger' :
				case 'function' :
				case 'inarray' :
					$$_key = ( string ) $_value;
					if ($_key == 'function' || $_key == 'inarray')
						$append .= ',' . strtoupper ( $_key ) . ",'$_value'";
					break;
				
				case 'caption' :
				case 'closetext' :
				case 'status' :
					$append .= ',' . strtoupper ( $_key ) . ",'" . str_replace ( "'", "'", $_value ) . "'";
					break;
				
				case 'fgcolor' :
				case 'bgcolor' :
				case 'textcolor' :
				case 'capcolor' :
				case 'closecolor' :
				case 'textfont' :
				case 'captionfont' :
				case 'closefont' :
				case 'fgbackground' :
				case 'bgbackground' :
				case 'caparray' :
				case 'capicon' :
				case 'background' :
				case 'frame' :
					$append .= ',' . strtoupper ( $_key ) . ",'$_value'";
					break;
				
				case 'textsize' :
				case 'captionsize' :
				case 'closesize' :
				case 'width' :
				case 'height' :
				case 'border' :
				case 'offsetx' :
				case 'offsety' :
				case 'snapx' :
				case 'snapy' :
				case 'fixx' :
				case 'fixy' :
				case 'padx' :
				case 'pady' :
				case 'timeout' :
				case 'delay' :
					$append .= ',' . strtoupper ( $_key ) . ",$_value";
					break;
				
				case 'sticky' :
				case 'left' :
				case 'right' :
				case 'center' :
				case 'above' :
				case 'below' :
				case 'noclose' :
				case 'autostatus' :
				case 'autostatuscap' :
				case 'fullhtml' :
				case 'hauto' :
				case 'vauto' :
				case 'mouseoff' :
				case 'followmouse' :
				case 'closeclick' :
				case 'wrap' :
					if ($_value)
						$append .= ',' . strtoupper ( $_key );
					break;
				
				default :
					$stemp->trigger_error ( _ ( "[popup] unknown parameter $_key" ) );
			}
		}
		
		if (empty ( $text ) && ! isset ( $inarray ) && empty ( $function )) {
			$stemp->trigger_error ( _ ( "overlib: attribute 'text' or 'inarray' or 'function' required" ) );
			return false;
		}
		
		if (empty ( $trigger )) {
			$trigger = "onmouseover";
		}
		
		$retval = $trigger . '="return overlib(\'' . preg_replace ( array ("!'!", '!"!', "![\r\n]!" ), array ("\'", "\'", '\r' ), $text ) . '\'';
		$retval .= $append . ');"';
		if ($trigger == 'onmouseover')
			$retval .= ' onmouseout="nd();"';
		
		return $retval;
	}

}
$html = new html ();

?>